==> bookio_fetchfox-0.10.7.tar.gz: bookio_fetchfox-0.10.7/fetchfox/rest.py <==
import asyncio
from typing import Tuple
import logging
import aiohttp
import backoff


logger = logging.getLogger(__name__)


@backoff.on_exception(backoff.expo, exception=Exception, max_time=60)
def get(url: str, headers: dict = None, params: dict = None, sleep: float = 0.05, timeout: float = None) -> Tuple[dict, int]:
    async def aux():
        client = aiohttp.ClientSession(
            timeout=aiohttp.ClientTimeout(total=timeout),
        )

        await asyncio.sleep(sleep)

        async with client as session:
            async with session.get(url, headers=headers, params=params) as response:
                json = await response.json()
                status_code = response.status

            await response.release()

        if status_code == 429:
            if "Retry-After" in response.headers:  # opensea.io
                wait = int(response.headers["Retry-After"]) + 5
                logger.info("too many requests, waiting for %ss", wait)
                await asyncio.sleep(wait)
                response.raise_for_status()
            elif json.get("detail") == "Request was throttled.":  # opensea.io
                wait = 90
            else:
                wait = 30

            logger.info("too many requests, waiting for %ss", wait)
            await asyncio.sleep(wait)
            response.raise_for_status()

        return json, status_code

    loop = asyncio.new_event_loop()
    asyncio.set_event_loop(loop)
    result = loop.run_until_complete(aux())
    loop.close()

    return result


@backoff.on_exception(backoff.expo, exception=Exception, max_time=60)
def post(url: str, body: dict = None, headers: dict = None, params: dict = None, sleep: float = 0.05, timeout: float = None) -> Tuple[dict, int]:
    async def aux():
        client = aiohttp.ClientSession(
            timeout=aiohttp.ClientTimeout(total=timeout),
        )

        await asyncio.sleep(sleep)

        async with client as session:
            async with session.post(url, json=body, headers=headers, params=params) as response:
                json = await response.json()
                status_code = response.status

                await response.release()

            if status_code == 429:
                if "Retry-After" in response.headers:  # opensea.io
                    wait = int(response.headers["Retry-After"]) + 5
                    logger.info("too many requests, waiting for %ss", wait)
                    await asyncio.sleep(wait)
                    response.raise_for_status()
                elif json.get("detail") == "Request was throttled.":  # opensea.io
                    wait = 90
                else:
                    wait = 30

                logger.info("too many requests, waiting for %ss", wait)
                await asyncio.sleep(wait)
                response.raise_for_status()

            return json, status_code

    loop = asyncio.new_event_loop()
    asyncio.set_event_loop(loop)
    result = loop.run_until_complete(aux())
    loop.close()

    return result

==> bookio_fetchfox-2.0.3.tar.gz: bookio_fetchfox-2.0.3/fetchfox/rest.py <==
import asyncio
import logging
from typing import Tuple
import json
import aiohttp
import backoff
from aiohttp.client_exceptions import ContentTypeError

logger = logging.getLogger(__name__)


@backoff.on_exception(backoff.expo, exception=Exception, max_time=60)
def get(url: str, headers: dict = None, params: dict = None, sleep: float = 0.05, timeout: float = None, check: str = None) -> Tuple[dict, int]:
    headers = {name: value for name, value in (headers or {}).items() if value is not None}
    params = {name: value for name, value in (params or {}).items() if value is not None}

    async def aux():
        client = aiohttp.ClientSession(
            timeout=aiohttp.ClientTimeout(total=timeout),
        )

        await asyncio.sleep(sleep)

        async with client as session:
            async with session.get(url, headers=headers, params=params) as response:
                status_code = response.status

                try:
                    json_content = await response.json()
                except ContentTypeError:
                    json_content = None

            await response.release()

        if status_code == 429:
            if "Retry-After" in response.headers:  # opensea.io
                wait = int(response.headers["Retry-After"]) + 5
                logger.info("too many requests, waiting for %ss", wait)
                await asyncio.sleep(wait)
                response.raise_for_status()
            elif json_content.get("detail") == "Request was throttled.":  # opensea.io
                wait = 90
            else:
                wait = 30

            logger.info("too many requests, waiting for %ss", wait)
            await asyncio.sleep(wait)
            response.raise_for_status()

        if check:
            assert json_content.get(check)

        return json_content, status_code

    loop = asyncio.new_event_loop()
    asyncio.set_event_loop(loop)
    result = loop.run_until_complete(aux())
    loop.close()

    return result


@backoff.on_exception(backoff.expo, exception=Exception, max_time=60)
def post(url: str, body: dict = None, headers: dict = None, params: dict = None, sleep: float = 0.05, timeout: float = None) -> Tuple[dict, int]:
    headers = {name: value for name, value in (headers or {}).items() if value is not None}
    params = {name: value for name, value in (params or {}).items() if value is not None}

    async def aux():
        client = aiohttp.ClientSession(
            timeout=aiohttp.ClientTimeout(total=timeout),
        )

        await asyncio.sleep(sleep)

        async with client as session:
            async with session.post(url, json=body, headers=headers, params=params) as response:
                status_code = response.status

                try:
                    json_content = await response.json()
                except ContentTypeError:
                    json_content = None

                await response.release()

            if status_code == 429:
                if "Retry-After" in response.headers:  # opensea.io
                    wait = int(response.headers["Retry-After"]) + 5
                    logger.info("too many requests, waiting for %ss", wait)
                    await asyncio.sleep(wait)
                    response.raise_for_status()
                elif json_content.get("detail") == "Request was throttled.":  # opensea.io
                    wait = 90
                else:
                    wait = 30

                logger.info("too many requests, waiting for %ss", wait)
                await asyncio.sleep(wait)
                response.raise_for_status()

            return json_content, status_code

    loop = asyncio.new_event_loop()
    asyncio.set_event_loop(loop)
    result = loop.run_until_complete(aux())
    loop.close()

    return result


@backoff.on_exception(backoff.expo, exception=Exception, max_time=60)
def get_stream(url: str, headers: dict = None, params: dict = None, sleep: float = 0.05, timeout: float = None, check: str = None) -> Tuple[dict, int]:
    headers = {name: value for name, value in (headers or {}).items() if value is not None}
    params = {name: value for name, value in (params or {}).items() if value is not None}

    async def aux():
        client = aiohttp.ClientSession(
            timeout=aiohttp.ClientTimeout(total=timeout),
        )

        await asyncio.sleep(sleep)

        async with client as session:
            async with session.get(url, headers=headers, params=params) as response:
                status_code = response.status

                try:
                    content = []

                    async for chunk in response.content:
                        content.append(json.loads(chunk.decode("utf-8")))

                    json_content = content
                except ContentTypeError:
                    json_content = None

            await response.release()

        if status_code == 429:
            if "Retry-After" in response.headers:  # opensea.io
                wait = int(response.headers["Retry-After"]) + 5
                logger.info("too many requests, waiting for %ss", wait)
                await asyncio.sleep(wait)
                response.raise_for_status()
            elif json_content.get("detail") == "Request was throttled.":  # opensea.io
                wait = 90
            else:
                wait = 30

            logger.info("too many requests, waiting for %ss", wait)
            await asyncio.sleep(wait)
            response.raise_for_status()

        if check:
            assert json_content.get(check)

        return json_content, status_code

    loop = asyncio.new_event_loop()
    asyncio.set_event_loop(loop)
    result = loop.run_until_complete(aux())
    loop.close()

    return result
